        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 19 <br>6,7,9,12,14,15,16,19,25,29,30,32,33,34,37,38,39,46,50';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 17 <br>1,3,4,8,10,11,13,17,20,22,23,28,31,36,42,45,49';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 10 <strong>control</strong><br>0,2,5,18,21,26,27,43,47,48';}
       if(rr==1 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 5 <br>24,35,40,41,44';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 19 <br>6,7,9,12,14,15,16,19,25,29,30,32,33,34,37,38,39,46,50';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 17 <br>1,3,4,8,10,11,13,17,20,22,23,28,31,36,42,45,49';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 10 <strong>control</strong><br>0,2,5,18,21,26,27,43,47,48';}
       if(rr==8 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 5 <br>24,35,40,41,44';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 19 <br>6,7,9,12,14,15,16,19,25,29,30,32,33,34,37,38,39,46,50';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 17 <br>1,3,4,8,10,11,13,17,20,22,23,28,31,36,42,45,49';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 10 <strong>control</strong><br>0,2,5,18,21,26,27,43,47,48';}
       if(rr==18 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 5 <br>24,35,40,41,44';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 19 <br>6,7,9,12,14,15,16,19,25,29,30,32,33,34,37,38,39,46,50';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 17 <br>1,3,4,8,10,11,13,17,20,22,23,28,31,36,42,45,49';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 10 <strong>control</strong><br>0,2,5,18,21,26,27,43,47,48';}
       if(rr==24 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 5 <br>24,35,40,41,44';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 19 <br>6,7,9,12,14,15,16,19,25,29,30,32,33,34,37,38,39,46,50';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 17 <br>1,3,4,8,10,11,13,17,20,22,23,28,31,36,42,45,49';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 10 <strong>control</strong><br>0,2,5,18,21,26,27,43,47,48';}
       if(rr==44 && cc==4){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 5 <br>24,35,40,41,44';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 19 <br>6,7,9,12,14,15,16,19,25,29,30,32,33,34,37,38,39,46,50';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 17 <br>1,3,4,8,10,11,13,17,20,22,23,28,31,36,42,45,49';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 10 <strong>control</strong><br>0,2,5,18,21,26,27,43,47,48';}
       if(rr==45 && cc==4){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 5 <br>24,35,40,41,44';}
}
