        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 19 <br>6,7,9,12,14,15,16,19,25,29,30,32,33,34,37,38,39,46,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 17 <br>1,3,4,8,10,11,13,17,20,22,23,28,31,36,42,45,49';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 10 <strong>control</strong><br>0,2,5,18,21,26,27,43,47,48';}
       if(rr==5 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 5 <br>24,35,40,41,44';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 19 <br>6,7,9,12,14,15,16,19,25,29,30,32,33,34,37,38,39,46,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 17 <br>1,3,4,8,10,11,13,17,20,22,23,28,31,36,42,45,49';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 10 <strong>control</strong><br>0,2,5,18,21,26,27,43,47,48';}
       if(rr==40 && cc==4){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 5 <br>24,35,40,41,44';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 19 <br>6,7,9,12,14,15,16,19,25,29,30,32,33,34,37,38,39,46,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 17 <br>1,3,4,8,10,11,13,17,20,22,23,28,31,36,42,45,49';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 10 <strong>control</strong><br>0,2,5,18,21,26,27,43,47,48';}
       if(rr==41 && cc==4){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 5 <br>24,35,40,41,44';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 19 <br>6,7,9,12,14,15,16,19,25,29,30,32,33,34,37,38,39,46,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 17 <br>1,3,4,8,10,11,13,17,20,22,23,28,31,36,42,45,49';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 10 <strong>control</strong><br>0,2,5,18,21,26,27,43,47,48';}
       if(rr==42 && cc==4){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 5 <br>24,35,40,41,44';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 19 <br>6,7,9,12,14,15,16,19,25,29,30,32,33,34,37,38,39,46,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>36</strong> miembros: 17 <br>1,3,4,8,10,11,13,17,20,22,23,28,31,36,42,45,49';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 10 <strong>control</strong><br>0,2,5,18,21,26,27,43,47,48';}
       if(rr==43 && cc==4){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260619 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 5 <br>24,35,40,41,44';}
}
